==> haskell-graphite-0.10.0.1-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-KwI2NiGr9Mo8QeqfbWj4Vh
key:                  graphite-0.10.0.1-KwI2NiGr9Mo8QeqfbWj4Vh
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  1b08eb02964bd4b5fc5dd5dfdacea32f
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-KwI2NiGr9Mo8QeqfbWj4Vh
depends:
    QuickCheck-2.14.3-1sWCe8KuaHp2ZxS22lbvKK base-4.16.4.0
    bytestring-0.11.4.0 cassava-0.5.3.1-5BMMoTn3Sb87BjSuRm40Xt
    containers-0.6.5.1 deepseq-1.4.6.1
    graphviz-2999.20.2.0-1gJS1InQfSzBg7iihV60nh
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal process-1.6.16.0
    random-1.2.1.2-4AOBQi3c93H3pMFoyiLFK6 text-1.2.5.0
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphite-0.10.0.1-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-EvzXwhdLmd93D7gDWqjdb
key:                  graphite-0.10.0.1-EvzXwhdLmd93D7gDWqjdb
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  ef720c18e226bc11223507c75635346b
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-EvzXwhdLmd93D7gDWqjdb
depends:
    QuickCheck-2.14.3-1sWCe8KuaHp2ZxS22lbvKK base-4.16.4.0
    bytestring-0.11.4.0 cassava-0.5.3.2-9gMTozQI8eX5A9PdhmzJIi
    containers-0.6.5.1 deepseq-1.4.6.1
    graphviz-2999.20.2.0-1gJS1InQfSzBg7iihV60nh
    hashable-1.4.4.0-CxCIesSa4aLFiFeBLAsQal process-1.6.16.0
    random-1.2.1.2-4AOBQi3c93H3pMFoyiLFK6 text-1.2.5.0
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q
    vector-0.13.1.0-HRMJcTNtHmH9PMIsGjP73X

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
